@@ -20,6 +20,7 @@ index((maplist), 2, apply, apply).
 index((maplist), 3, apply, apply).
 index((maplist), 4, apply, apply).
 index((maplist), 5, apply, apply).
+index((convlist), 3, apply, apply).
 index((foldl), 4, apply, apply).
 index((foldl), 5, apply, apply).
 index((foldl), 6, apply, apply).
@@ -115,11 +116,14 @@ index((index), 1, backward_compatibility, backcomp).
 index((hash), 1, backward_compatibility, backcomp).
 index((set_base_module), 1, backward_compatibility, backcomp).
 index((eval_license), 0, backward_compatibility, backcomp).
+index((trie_insert_new), 3, backward_compatibility, backcomp).
 index((base32), 2, base32, base32).
 index((base32), 3, base32, base32).
+index((base64_encoded), 3, base64, base64).
+index((base64_encoded), 4, base64, base64).
 index((base64), 2, base64, base64).
-index((base64url), 2, base64, base64).
 index((base64), 3, base64, base64).
+index((base64url), 2, base64, base64).
 index((base64url), 3, base64, base64).
 index((bdb_init), 1, bdb, bdb).
 index((bdb_init), 2, bdb, bdb).
@@ -195,6 +199,7 @@ index((with_output_to_codes), 2, codesio, codesio).
 index((with_output_to_codes), 3, codesio, codesio).
 index((with_output_to_codes), 4, codesio, codesio).
 index((coinductive), 1, coinduction, coinduction).
+index((crypto_n_random_bytes), 2, crypto, crypto).
 index((crypto_data_hash), 3, crypto, crypto).
 index((crypto_file_hash), 3, crypto, crypto).
 index((crypto_context_new), 2, crypto, crypto).
@@ -202,10 +207,13 @@ index((crypto_data_context), 3, crypto, crypto).
 index((crypto_context_hash), 2, crypto, crypto).
 index((crypto_open_hash_stream), 3, crypto, crypto).
 index((crypto_stream_hash), 2, crypto, crypto).
+index((crypto_password_hash), 2, crypto, crypto).
+index((crypto_password_hash), 3, crypto, crypto).
+index((crypto_data_hkdf), 4, crypto, crypto).
 index((ecdsa_sign), 4, crypto, crypto).
 index((ecdsa_verify), 4, crypto, crypto).
-index((evp_decrypt), 6, crypto, crypto).
-index((evp_encrypt), 6, crypto, crypto).
+index((crypto_data_decrypt), 6, crypto, crypto).
+index((crypto_data_encrypt), 6, crypto, crypto).
 index((hex_bytes), 2, crypto, crypto).
 index((rsa_private_decrypt), 4, crypto, crypto).
 index((rsa_private_encrypt), 4, crypto, crypto).
@@ -213,12 +221,21 @@ index((rsa_public_decrypt), 4, crypto, crypto).
 index((rsa_public_encrypt), 4, crypto, crypto).
 index((rsa_sign), 4, crypto, crypto).
 index((rsa_verify), 4, crypto, crypto).
+index((crypto_modular_inverse), 3, crypto, crypto).
+index((crypto_generate_prime), 3, crypto, crypto).
+index((crypto_is_prime), 2, crypto, crypto).
+index((crypto_name_curve), 2, crypto, crypto).
+index((crypto_curve_order), 2, crypto, crypto).
+index((crypto_curve_generator), 2, crypto, crypto).
+index((crypto_curve_scalar_mult), 4, crypto, crypto).
 index((crypt), 2, crypt, crypt).
 index((csv), 3, csv, csv).
 index((csv), 4, csv, csv).
 index((csv_read_file), 2, csv, csv).
 index((csv_read_file), 3, csv, csv).
 index((csv_read_file_row), 3, csv, csv).
+index((csv_read_row), 3, csv, csv).
+index((csv_options), 2, csv, csv).
 index((csv_write_file), 2, csv, csv).
 index((csv_write_file), 3, csv, csv).
 index((csv_write_stream), 3, csv, csv).
@@ -276,6 +293,7 @@ index((dicts_to_compounds), 4, dicts, dicts).
 index((dif), 2, dif, dif).
 index((doc_save), 2, pldoc_files, doc_files).
 index((doc_pack), 1, pldoc_files, doc_files).
+index((doc_enable), 1, pldoc_http, doc_http).
 index((doc_server), 1, pldoc_http, doc_http).
 index((doc_server), 2, pldoc_http, doc_http).
 index((doc_browser), 0, pldoc_http, doc_http).
@@ -316,6 +334,7 @@ index((fast_write), 2, fastrw, fastrw).
 index((fast_write_to_string), 3, fastrw, fastrw).
 index((set_time_file), 3, files_ex, filesex).
 index((link_file), 3, files_ex, filesex).
+index((chmod), 2, files_ex, filesex).
 index((relative_file_name), 3, files_ex, filesex).
 index((directory_file_path), 3, files_ex, filesex).
 index((copy_file), 2, files_ex, filesex).
@@ -480,6 +499,7 @@ index((odbc_fetch), 3, odbc, odbc).
 index((odbc_close_statement), 1, odbc, odbc).
 index((odbc_clone_statement), 2, odbc, odbc).
 index((odbc_free_statement), 1, odbc, odbc).
+index((odbc_cancel_thread), 1, odbc, odbc).
 index((odbc_current_table), 2, odbc, odbc).
 index((odbc_current_table), 3, odbc, odbc).
 index((odbc_table_column), 3, odbc, odbc).
@@ -541,6 +561,16 @@ index((pairs_keys), 2, pairs, pairs).
 index((group_pairs_by_key), 2, pairs, pairs).
 index((transpose_pairs), 2, pairs, pairs).
 index((map_list_to_pairs), 3, pairs, pairs).
+index((re_match), 2, pcre, pcre).
+index((re_match), 3, pcre, pcre).
+index((re_matchsub), 4, pcre, pcre).
+index((re_foldl), 6, pcre, pcre).
+index((re_split), 3, pcre, pcre).
+index((re_split), 4, pcre, pcre).
+index((re_replace), 4, pcre, pcre).
+index((re_compile), 3, pcre, pcre).
+index((re_flush), 0, pcre, pcre).
+index((re_config), 1, pcre, pcre).
 index((pdt_install_console), 0, pdt_console, pdt_console).
 index((pengine_writeln), 1, pengines_io, pengines_io).
 index((pengine_nl), 0, pengines_io, pengines_io).
@@ -557,6 +587,8 @@ index((pengine_listing), 0, pengines_io, pengines_io).
 index((pengine_listing), 1, pengines_io, pengines_io).
 index((pengine_portray_clause), 1, pengines_io, pengines_io).
 index((pengine_read), 1, pengines_io, pengines_io).
+index((pengine_read_line_to_string), 2, pengines_io, pengines_io).
+index((pengine_read_line_to_codes), 2, pengines_io, pengines_io).
 index((pengine_io_predicate), 1, pengines_io, pengines_io).
 index((pengine_bind_io_to_html), 1, pengines_io, pengines_io).
 index((pengine_io_goal_expansion), 2, pengines_io, pengines_io).
@@ -564,6 +596,7 @@ index((persistent), 1, persistency, persistency).
 index((current_persistent_predicate), 1, persistency, persistency).
 index((db_attach), 2, persistency, persistency).
 index((db_detach), 0, persistency, persistency).
+index((db_attached), 1, persistency, persistency).
 index((db_sync), 1, persistency, persistency).
 index((db_sync_all), 1, persistency, persistency).
 index((doc_collect), 1, pldoc, pldoc).
@@ -629,6 +662,8 @@ index((format_spec), 3, prolog_format, prolog_format).
 index((format_types), 2, prolog_format, prolog_format).
 index((prolog_history), 1, prolog_history, prolog_history).
 index((qcompile_libraries), 0, prolog_install, prolog_install).
+index((jiti_list), 0, prolog_jiti, prolog_jiti).
+index((jiti_list), 1, prolog_jiti, prolog_jiti).
 index((infer_meta_predicate), 2, prolog_metainference, prolog_metainference).
 index((inferred_meta_predicate), 2, prolog_metainference, prolog_metainference).
 index((pack_list_installed), 0, prolog_pack, prolog_pack).
@@ -943,6 +978,8 @@ index((udp_send), 4, socket, socket).
 index((negotiate_socks_connection), 2, socket, socket).
 index((distinct), 1, solution_sequences, solution_sequences).
 index((distinct), 2, solution_sequences, solution_sequences).
+index((reduced), 1, solution_sequences, solution_sequences).
+index((reduced), 3, solution_sequences, solution_sequences).
 index((limit), 2, solution_sequences, solution_sequences).
 index((offset), 2, solution_sequences, solution_sequences).
 index((order_by), 2, solution_sequences, solution_sequences).
@@ -957,11 +994,12 @@ index((system_root_certificates), 1, ssl, ssl).
 index((cert_accept_any), 5, ssl, ssl).
 index((ssl_context), 3, ssl, ssl).
 index((ssl_add_certificate_key), 4, ssl, ssl).
-index((ssl_set_sni_hook), 3, ssl, ssl).
+index((ssl_set_options), 3, ssl, ssl).
 index((ssl_negotiate), 5, ssl, ssl).
 index((ssl_peer_certificate), 2, ssl, ssl).
 index((ssl_peer_certificate_chain), 2, ssl, ssl).
 index((ssl_session), 2, ssl, ssl).
+index((ssl_secure_ciphers), 1, ssl, ssl).
 index((statistics), 0, prolog_statistics, statistics).
 index((statistics), 1, prolog_statistics, statistics).
 index((thread_statistics), 2, prolog_statistics, statistics).
@@ -1038,8 +1076,10 @@ index((thread_run_interactor), 0, thread_util, threadutil).
 index((threads), 0, thread_util, threadutil).
 index((join_threads), 0, thread_util, threadutil).
 index((interactor), 0, thread_util, threadutil).
+index((interactor), 1, thread_util, threadutil).
 index((thread_has_console), 0, thread_util, threadutil).
 index((attach_console), 0, thread_util, threadutil).
+index((attach_console), 1, thread_util, threadutil).
 index((tspy), 1, thread_util, threadutil).
 index((tspy), 2, thread_util, threadutil).
 index((tdebug), 0, thread_util, threadutil).
@@ -1156,6 +1196,7 @@ index((expand_url_path), 2, www_browser, www_browser).
 index((xmld_signed_DOM), 3, xmldsig, xmldsig).
 index((xmld_verify_signature), 4, xmldsig, xmldsig).
 index((decrypt_xml), 4, xmlenc, xmlenc).
+index((load_certificate_from_base64_string), 2, xmlenc, xmlenc).
 index((xpath), 3, xpath, xpath).
 index((xpath_chk), 3, xpath, xpath).
 index((xsdp_type), 1, xsdp_type, xsdp_types).
